@@ -9,6 +9,7 @@ from selenium import webdriver
 from selenium_profiles.scripts import profiles
 from selenium_profiles.scripts.cdp_tools import cdp_tools
 from selenium_profiles.scripts.driver_utils import sendkeys
+from selenium_profiles.scripts import undetected
 from selenium_profiles.utils.utils import sel_profiles_path, find_chrome_executable  # read txt files
 
 
@@ -68,17 +69,12 @@ class driver(object):
             self.driver = uc.Chrome(use_subprocess=True, options=self.options, keep_alive=True,
                                     browser_executable_path=find_chrome_executable())  # start undetected_chromedriver
         else:
-            # undetected options
-            self.options.add_experimental_option("excludeSwitches", ["enable-automation"])
-            self.options.add_experimental_option('useAutomationExtension', False)
-            self.options.arguments.extend(["--no-default-browser-check", "--no-first-run"])  # suppress welcome
-            self.options.arguments.extend(["--no-default-browser-check", "--no-first-run"])
-            self.options.arguments.extend(["--disable-blink-features=AutomationControlled", "--disable-blink-features"])
+            self.options = undetected.config_options(self.options)
 
             # Actual start of chrome
             self.driver = webdriver.Chrome(options=self.options)  # start selenium webdriver
 
-        self.driver.get('http://icanhazip.com/')  # wait browser to start
+        self.driver.get('http://motherfuckingwebsite.com/')  # wait browser to start
 
         self.cdp_tools = cdp_tools(self.driver)
 
@@ -87,24 +83,12 @@ class driver(object):
 
         self.profiles.exec_js_evaluators(self.profile, self.driver, self.cdp_tools)
 
+        if not uc_driver:
+            undetected.exec_cdp(self.driver, self.cdp_tools)
+
         if not (profile["plugins"]["modheader"] is False):
             self.load_header_profiles(profile["plugins"]["modheader"])
 
-        # set webdriver js var to false
-        self.cdp_tools.evaluate_on_new_document("""
-                            Object.defineProperty(window, 'navigator', {
-                                value: new Proxy(navigator, {
-                                        has: (target, key) => (key === 'webdriver' ? false : key in target),
-                                        get: (target, key) =>
-                                                key === 'webdriver' ?
-                                                false :
-                                                typeof target[key] === 'function' ?
-                                                target[key].bind(target) :
-                                                target[key]
-                                        })
-                            });
-                            """)
-
         self.driver.profile = profile
         self.add_funcs_to_driver()
 
